==> haskell-hsyaml-aeson-0.2.0.2-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsYAML-aeson
version:              0.2.0.2
visibility:           public
id:                   HsYAML-aeson-0.2.0.2-HssZzCoOHY8HKLbZbWvoqX
key:                  HsYAML-aeson-0.2.0.2-HssZzCoOHY8HKLbZbWvoqX
license:              GPL-2.0-or-later
copyright:            2018-2019 Herbert Valerio Riedel
maintainer:           Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             JSON to YAML Adapter
description:
    The [YAML 1.2](https://yaml.org/spec/1.2/spec.html) format provides
    a much richer data-model and feature-set
    than the [JavaScript Object Notation (JSON)](https://tools.ietf.org/html/rfc7159) format.
    However, sometimes it'\''s desirable to ignore the extra capabilities
    and treat YAML as if it was merely a more convenient markup format
    for humans to write JSON data. To this end this module provides a
    compatibility layer atop [HsYAML](https://hackage.haskell.org/package/HsYAML)
    which allows decoding YAML documents in the more limited JSON data-model while also providing
    convenience by reusing [aeson](https://hackage.haskell.org/package/aeson)'\''s
    '\''FromJSON'\'' instances for decoding the YAML data into native Haskell data types.

category:             Text, Codec, Web, JSON, YAML
abi:                  1c904761251e4ef264b3c231b58db8ad
exposed:              True
exposed-modules:      Data.YAML.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyaml-aeson
hs-libraries:         HSHsYAML-aeson-0.2.0.2-HssZzCoOHY8HKLbZbWvoqX
depends:
    HsYAML-0.2.1.5-IMd0WrHgXneJs1QNLKUhYx
    aeson-2.1.2.1-wY4CXNP4Ti6TCaMY1tyMf base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.2.2
    scientific-0.3.8.0-DLDr5nembSsHeUMWxBP2Rn text-2.0.2
    unordered-containers-0.2.20-BdnqkwZm9bx6ocoMK9HG74
    vector-0.13.2.0-B5pfN7kp2sVHpMWItbJQ58

haddock-interfaces:
    /usr/share/doc/haskell-hsyaml-aeson/html/HsYAML-aeson.haddock

haddock-html:         /usr/share/doc/haskell-hsyaml-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsyaml-aeson-0.2.0.2-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hsyaml-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsYAML-aeson
version:              0.2.0.2
visibility:           public
id:                   HsYAML-aeson-0.2.0.2-AQ7Lvp7TPivA6So7z4hcKH
key:                  HsYAML-aeson-0.2.0.2-AQ7Lvp7TPivA6So7z4hcKH
license:              GPL-2.0-or-later
copyright:            2018-2019 Herbert Valerio Riedel
maintainer:           Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             JSON to YAML Adapter
description:
    The [YAML 1.2](https://yaml.org/spec/1.2/spec.html) format provides
    a much richer data-model and feature-set
    than the [JavaScript Object Notation (JSON)](https://tools.ietf.org/html/rfc7159) format.
    However, sometimes it'\''s desirable to ignore the extra capabilities
    and treat YAML as if it was merely a more convenient markup format
    for humans to write JSON data. To this end this module provides a
    compatibility layer atop [HsYAML](https://hackage.haskell.org/package/HsYAML)
    which allows decoding YAML documents in the more limited JSON data-model while also providing
    convenience by reusing [aeson](https://hackage.haskell.org/package/aeson)'\''s
    '\''FromJSON'\'' instances for decoding the YAML data into native Haskell data types.

category:             Text, Codec, Web, JSON, YAML
abi:                  3752e9487294e40fe7e1cfa280ff4acb
exposed:              True
exposed-modules:      Data.YAML.Aeson
import-dirs:          /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HsYAML-aeson-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyaml-aeson
hs-libraries:         HSHsYAML-aeson-0.2.0.2-AQ7Lvp7TPivA6So7z4hcKH
depends:
    HsYAML-0.2.1.5-9Q7JMfWThqeRhfi9LlaVz
    aeson-2.1.2.1-Eu0ZMA1fvZJ7acphaZ1YUp base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.2.2
    scientific-0.3.8.0-hGLqISimekA59HuDEk96u text-2.0.2
    unordered-containers-0.2.20-5YE9FG6zPmjDjdA4DCPpEY
    vector-0.13.2.0-2If6MrCrP3g55Bnhb5dowG

haddock-interfaces:
    /usr/share/doc/haskell-hsyaml-aeson/html/HsYAML-aeson.haddock

haddock-html:         /usr/share/doc/haskell-hsyaml-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
